from unittest import TestCase 

from crawlfish.crawler.get_url_parts import get_url_parts








class Test_get_url_parts(TestCase):

	def test_get_url_parts(self):
		test_url = "https://site.com/a/b/c/d"
		parts =  get_url_parts(test_url)
		print("PARTS " , parts)
		expected_outcome = [ 'https://site.com/a', 'https://site.com/a/b',
					'https://site.com/a/b/c' ]
		self.assertTrue(len(parts ) == 3)
		self.assertTrue(expected_outcome == parts)




from unittest import TestCase

from crawlfish.crawler import extract_file_info_from_url



class Test_extract_file_info_from_url(TestCase):

	def test_func(self):
		# basic scenario
		test_url = "http://www.site.com/video.mp4?jkdhflsdfhlgfbfdshbf"
		file , ext  = extract_file_info_from_url(test_url)
		self.assertTrue(file == "video.mp4")
		self.assertTrue(ext == '.mp4')
		# unclear extension scenario
		test_url = "http://www.site.com/file.min.js?jkdhflsdfhlgfbfdshbf"
		file , ext  = extract_file_info_from_url(test_url)
		print("FILE" , file , "ext" , ext)
		self.assertTrue(file == "file.min.js")
		self.assertTrue(ext == '.js')
		


import os , bs4
from bs4 import BeautifulSoup
from unittest import TestCase


from crawlfish.http import get_page 

test_link = "https://stackoverflow.com/"
test_output_file  = "tests/test_data/test_get_stackoverflow_page.html"




class TestHttpGet(TestCase):

	def test_get_page(self):
		'''
		Test if we can fetch a web page in an expected way 
		'''

		page = get_page(test_link)
		self.assertTrue(len(page) > 0)

	def test_get_and_save_page(self):
		'''
		Test if we can fetch a web page and save the contents in a file 
		'''
		if os.path.isfile(test_output_file):
			os.remove(test_output_file)
		page = get_page(test_link , output_file = test_output_file)
		self.assertTrue(len(page) > 0)
		self.assertTrue(os.path.isfile(test_output_file))
		with open(test_output_file , "r" ,encoding='utf-8') as f:
			data = f.read() 
			soup = BeautifulSoup(data , "html.parser")
			self.assertTrue(len(data) > 0 ) # contains something 
			logo_span = soup.find("span" , {"class":"-img _glyph"})
			self.assertTrue(type(logo_span) == bs4.Tag)
			self.assertTrue('Stack Overflow' in logo_span.text)




from unittest import TestCase

from crawlfish.crawler.ensure_url_format  import ensure_url_format

from .test_soups import elements_to_find_soup



class Test_ensureurlformat_function(TestCase):
	def test_func(self):
		base_url = "https://site.com" 
		test_link = '/cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js'
		expected_result = base_url  + test_link
		res = ensure_url_format(base_url, test_link)
		print('RESULT' , res)
		self.assertTrue(res == expected_result)




from crawlfish.crawler.explore_webpage import explore_webpage
from crawlfish import get_page
from unittest import TestCase 


def test_get_function(url):
	html = get_page(url , output_file = "tests/test_data/test_explore_webpage.html")
	return html
class Test_explore_webpage(TestCase):

	def test_page_report_returned(self):
		report = explore_webpage('https://amazon.com/' , test_get_function)
		# print(report.same_site_urls)
		expected_netloc = 'amazon.com'
		self.assertTrue(report.split_url.netloc == expected_netloc)


import json
from unittest import TestCase

from configparser import ConfigParser
from crawlfish.crawler.website_report import WebsiteReport
from crawlfish.crawler.url_to_folder_name import url_to_folder_name
from crawlfish.crawler import explore_webpage
from .test_soups import test_internal_static_soup

 

def test_get_url_function(url):

	return test_internal_static_soup



class TestwebsiteReportClass(TestCase):

	def test_save_fll_report(self):
		test_link = "https://supplypost.com"
		test_output_folder = "tests/test_data/test_save_web_report_function"
		page_reports ={ url_to_folder_name(test_link):explore_webpage(test_link  ) }
		report = WebsiteReport(page_reports)
		report.save(output_folder = test_output_folder , redownload_static = True)
		print(report.__repr__())


import os 
from unittest import TestCase

from crawlfish.crawlfish_utils import check_file



test_image_file = "tests/test_data/test_check_file/image.png"
test_text_file = "tests/test_data/test_check_file/some-file.txt"



class Test_check_file(TestCase):

	def test_func(self):
		if os.path.isfile(test_text_file):
			os.remove(test_text_file)
		check_file(test_text_file , make_if_none = False )
		self.assertFalse(os.path.isfile(test_text_file))
		check_file(test_text_file , make_if_none = True )
		self.assertTrue(os.path.isfile(test_text_file))
		


from unittest import TestCase 

from crawlfish.crawler.url_to_folder_name import url_to_folder_name



class Test_url_to_folder_name(TestCase):

	def test_get_url_parts(self):
		test_url = "https://site.uk/a/b/c/d"
		name =  url_to_folder_name(test_url)
		print("Test folder name generated " ,name)
		expected_outcome = "site__a_b_c_d"
		self.assertTrue(expected_outcome == name)

		test_url = "http://www.sample-videos.com/contact.php"
		name =  url_to_folder_name(test_url)
		print("Test folder name generated " ,name)
		expected_outcome = "sample_videos__contact_php"
		self.assertTrue(expected_outcome == name)



import os 
from crawlfish.crawler import download_image ,download_images
from unittest import TestCase 

test_image_urls = ['https://www.sample-videos.com/img/Sample-jpg-image-50kb.jpg','https://www.sample-videos.com/img/Sample-jpg-image-100kb.jpg']
test_output_folder ="tests/test_data/test_download_images/"

class Test_download_image_function(TestCase):
	def test_download_image(self):
		test_file ="tests/google.png"
		test_link = 'https://www.google.com/images/branding/googlelogo/1x/googlelogo_light_color_272x92dp.png'
		if os.path.isfile(test_file):
			os.remove(test_file)
		base_name , image_data = download_image( test_link , output_folder = test_output_folder)
		self.assertTrue(base_name == "googlelogo_light_color_272x92dp.png")


	def test_download_images(self):
		expected_path = os.path.join(test_output_folder , 'Sample-jpg-image-50kb.jpg')
		if os.path.isfile(expected_path):
			os.remove(expected_path)
		image_data = download_images(test_image_urls , output_folder = test_output_folder)
		self.assertTrue(os.path.isfile(expected_path))
		self.assertTrue('Sample-jpg-image-50kb.jpg' in image_data.keys())


import json
import os
from unittest import TestCase

from configparser import ConfigParser
from crawlfish.crawler.webpage_report import WebpageReport
from crawlfish import explore_webpage

from .test_soups import test_internal_static_soup

test_js_tags =  test_internal_static_soup.find_all("script")
test_css_tags =  test_internal_static_soup.find_all("style")

test_static_output_folder = 'tests/test_data/test_download_static_by_webpage_report/'

test_section_name , test_section_key = "urls", "network_location"
expected_network_location = "www.sample-videos.com"
test_url = "https://www.sample-videos.com/"

def test_get_url_function(url):

	return test_internal_static_soup


class TestWebpageReportClass(TestCase):

	def test_save_as(self):
		test_page_report = WebpageReport(test_url)
		dict_form = test_page_report.as_dict()
		self.assertTrue(type(dict_form) == dict )

		# config file
		test_file = "tests/test_data/page_report_config.ini"
		test_page_report.save_to_config_file(test_file)
		cp = ConfigParser()
		cp.read(test_file)
		self.assertTrue(len(cp.sections()) != 0)
		self.assertTrue(cp[test_section_name][test_section_key] == expected_network_location)

		# text file 
		test_file = "tests/test_data/page_report_text.txt"
		test_page_report.save_to_text_file(test_file)
		with open(test_file , "r") as f:
			self.assertTrue(f.read() == test_page_report.as_text())

		# json 
		test_file = "tests/test_data/page_report_json.json"
		test_page_report.save_to_json_file(test_file)
		with open(test_file ,"r") as f:
			data = json.load(f)
			dct = dict(data)
			self.assertTrue(dct[test_section_name][test_section_key] == expected_network_location)

	def test_extract_internal_code(self):
		''' '''
		test_page_report =   WebpageReport(test_url  , js_tags = test_js_tags , css_tags = test_css_tags)
		self.assertTrue("somescript1" in test_page_report.internal_js_code.values())
		self.assertTrue("somestyle2" in test_page_report.internal_css_code.values())

	def test_download_static_code(self):
		test_css_urls = ['https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/font/bootstrap-icons.css','https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.3.1/css/all.min.css']
		test_js_urls = ['https://ajax.googleapis.com/ajax/libs/jquery/3.7.1/jquery.min.js','https://unpkg.com/leaflet@1.9.4/dist/leaflet.js']
		test_page_report =   WebpageReport(test_url  , js_urls = test_js_urls , css_urls = test_css_urls, js_tags = test_js_tags , css_tags = test_css_tags)
		test_page_report.FetchExternalCode()
		test_page_report.save_js_code(output_folder = test_static_output_folder )
		test_page_report.save_css_code(output_folder = test_static_output_folder)

	def test_download_images(self):
		expected_output_file = os.path.join( test_static_output_folder + 'images' , "googlelogo_light_color_272x92dp.png",)
		if os.path.isfile(expected_output_file):
			os.remove(expected_output_file)
		test_image_urls = [ 'https://www.google.com/images/branding/googlelogo/1x/googlelogo_light_color_272x92dp.png',]
		test_page_report =   WebpageReport(test_url , image_urls = test_image_urls)
		test_page_report.FetchImages()
		test_page_report.save_images(test_static_output_folder)
		self.assertTrue(os.path.isfile(expected_output_file))
		
	def test_get_other_site_urls(self):
		test_page_report =   explore_webpage("https://site.com" , get_function = test_get_url_function)
		self.assertTrue("https://othersite.com" in test_page_report.other_site_urls)

	def test_save(self):
		test_page_report =   explore_webpage("https://amazon.com")
		print("STATIC URLS")
		print(test_page_report.js_urls)
		print(test_page_report.css_urls)
		test_page_report.save("tests/test_data/test_save_webpage_report" , name_space = True)
		print("URLS " , test_page_report.other_site_urls , test_page_report.same_site_urls)


 



import os 
from crawlfish.crawler import download_static_code_file
from unittest import TestCase 


class Test_download_static_code_file_function(TestCase):
	def test_download_static_code_file(self):
		test_file ="tests/test_data/JQUERY_js.js"
		if os.path.isfile(test_file):
			os.remove(test_file)
		test_link = "https://ajax.googleapis.com/ajax/libs/jquery/3.7.1/jquery.min.js"
		expected_content = '''e=this.originalEvent;this.isDefaultPrevented=Ne,e&&!this.isSimulated&&e.preventDefault()}'''
		base_name , code  = download_static_code_file( test_link	 ,file= test_file )
		print("base_name extracts" , base_name)
		self.assertTrue(base_name == 'JQUERY_js.js')
		self.assertTrue(expected_content in  code)
		with open(test_file  , "r" ,encoding = "utf-8") as f:
			self.assertTrue(expected_content in f.read())


		# test a lnik with arguments
		test_link = 'https://www.google.com/recaptcha/api.js?render=explicit'
		base_name , code = download_static_code_file(test_link)
		self.assertTrue(base_name == 'api.js')
		




from unittest import TestCase 


from .test_soups import grocery_list_soup

from crawlfish.html import get_element_text , get_elements_text

test_soup = grocery_list_soup

class TestGettingElementText(TestCase):

	def test_get_element_text(self):
		expected_text = "listHeading"
		heading_element = test_soup.find("h1" , {"class":"list-heading"})
		text = get_element_text(heading_element)
		self.assertTrue(text == expected_text)


	def test_get_elements_text(self):
		expected_result = [  'Milk', 'Pears' , "Oranges" , 'Tomatoes' , 'Cheese' ]
		texts = get_elements_text(test_soup ,tag_name = 'li', attribute =  'class' , attribute_value = 'grocery-list-item')
		print("TEST RESULT : " , texts)
		self.assertTrue(expected_result == texts)


 

import setuptools
from setuptools import setup, find_packages

long_description = ""
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="crawlfish",
    version="0.0.2",
    author="Victor Kipkemboi",
    author_email="scriptilapia@gmail.com",
    long_description =long_description,
    long_description_content_type="text/markdown",
    description="""An easy to use web crawling library for exploring whole websites and webpages , element searching , handy bs4 related shortcuts , generic web scraping functions  and  more  """,
    url="https://github.com/victhepythonista/crawlfish",
    project_urls={
        "Bug Tracker": "https://github.com/victhepythonista/crawlfish/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License"
    ],
    packages=[],
    python_requires=">=3.6",
 
)